@@ -732,39 +732,6 @@ sub get_test_params {
     return $result;
 }
 
-# Standatd SQL, can be here
-sub get_batch_job_result {
-    my ( $self, $batch_id ) = @_;
-
-    die Zonemaster::Backend::Error::ResourceNotFound->new( message => "Unknown batch", data => { batch_id => $batch_id } )
-        unless defined $self->batch_exists_in_db( $batch_id );
-
-    my $dbh = $self->dbh;
-
-    my %result;
-    $result{nb_running} = 0;
-    $result{nb_finished} = 0;
-
-    my $query = "
-        SELECT hash_id, progress
-        FROM test_results
-        WHERE batch_id=?";
-
-    my $sth1 = $dbh->prepare( $query );
-    $sth1->execute( $batch_id );
-    while ( my $h = $sth1->fetchrow_hashref ) {
-        if ( $h->{progress} eq '100' ) {
-            $result{nb_finished}++;
-            push(@{$result{finished_test_ids}}, $h->{hash_id});
-        }
-        else {
-            $result{nb_running}++;
-        }
-    }
-
-    return \%result;
-}
-
 =head2 batch_status
 
 Returns number of tests per category (finished, running, waiting) for the given
