@@ -101,6 +101,61 @@ sub create_schema {
         'CREATE INDEX IF NOT EXISTS test_results__progress_priority_id ON test_results (progress, priority DESC, id) WHERE (progress = 0)'
     );
 
+    ####################################################################
+    # LOG LEVEL
+    ####################################################################
+    $dbh->do(
+        "CREATE TABLE IF NOT EXISTS log_level (
+            value INT,
+            level VARCHAR(15),
+
+            UNIQUE (value)
+        )
+        "
+    ) or die Zonemaster::Backend::Error::Internal->new( reason => "PostgreSQL error, could not create 'log_level' table", data => $dbh->errstr() );
+    my ( $c ) = $dbh->selectrow_array( "SELECT count(*) FROM log_level" );
+    if ( $c == 0 ) {
+        $dbh->do(
+            "INSERT INTO log_level (value, level)
+            VALUES
+                (-2, 'DEBUG3'),
+                (-1, 'DEBUG2'),
+                ( 0, 'DEBUG'),
+                ( 1, 'INFO'),
+                ( 2, 'NOTICE'),
+                ( 3, 'WARNING'),
+                ( 4, 'ERROR'),
+                ( 5, 'CRITICAL')
+            "
+        );
+    }
+
+    ####################################################################
+    # RESULT ENTRIES
+    ####################################################################
+    $dbh->do(
+        'CREATE TABLE IF NOT EXISTS result_entries (
+            hash_id VARCHAR(16) NOT NULL,
+            level INT NOT NULL,
+            module VARCHAR(255) NOT NULL,
+            testcase VARCHAR(255) NOT NULL,
+            tag VARCHAR(255) NOT NULL,
+            timestamp REAL NOT NULL,
+            args JSONb NOT NULL,
+
+            CONSTRAINT fk_hash_id FOREIGN KEY (hash_id) REFERENCES test_results(hash_id),
+            CONSTRAINT fk_level FOREIGN KEY(level) REFERENCES log_level(value)
+        )
+        '
+    ) or die Zonemaster::Backend::Error::Internal->new( reason => "PostgreSQL error, could not create 'result_entries' table", data => $dbh->errstr() );
+
+    $dbh->do(
+        'CREATE INDEX IF NOT EXISTS result_entries__hash_id ON result_entries (hash_id)'
+    );
+
+    $dbh->do(
+        'CREATE INDEX IF NOT EXISTS result_entries__level ON result_entries (level)'
+    );
 
     ####################################################################
     # BATCH JOBS
@@ -148,7 +203,9 @@ sub drop_tables {
     $self->dbh->do( "SET client_min_messages = warning" );
 
     try {
-        $self->dbh->do( "DROP TABLE IF EXISTS test_results" );
+        $self->dbh->do( "DROP TABLE IF EXISTS test_results CASCADE" );
+        $self->dbh->do( "DROP TABLE IF EXISTS result_entries CASCADE" );
+        $self->dbh->do( "DROP TABLE IF EXISTS log_level" );
         $self->dbh->do( "DROP TABLE IF EXISTS users" );
         $self->dbh->do( "DROP TABLE IF EXISTS batch_jobs" );
     }
